@@ -18,7 +18,7 @@ DO_MYSQL_DBNAME=test
 DO_MYSQL_DATABASE=/${DO_MYSQL_DBNAME}
 
 /usr/sbin/mysqld --no-defaults --initialize-insecure --datadir=${MYTEMP_DIR} --user=${DO_MYSQL_USER}
-/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking --secure-file-priv=  &
+/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking --local-infile=1 --secure-file-priv=  &
 echo -n pinging mysqld.
 attempts=0
 while ! /usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} ping ; do
@@ -36,4 +36,4 @@ cleanup() {
 }
 trap cleanup INT EXIT TERM
 
-"$@"
+$@ || exit $?
